plot_set <- emergency |>
head(500) |>
thicken("hour", "h") |>
dplyr::count(h)
# this will show the data on the full hour
ggplot2::ggplot(plot_set, ggplot2::aes(h, n)) +
ggplot2::geom_col()
# adding a character to indicate the hours of the interval.
plot_set |>
dplyr::mutate(h_int = format_interval(h, "%H", sep = "-"))
Run the code above in your browser using DataLab