View source: R/fill_functions.R
| fill_by_prevalent | R Documentation |
For each specified column in x replace the missing values by the most
prevalent nonmissing value.
fill_by_prevalent(x, ...)
x |
A data frame. |
... |
The unquoted column names of the variables that should be filled. |
x with the altered columns.
x <- seq(as.Date("2016-01-01"), by = "day", length.out = 366)
x <- x[sample(1:366, 200)] |> sort()
x_df <- data.frame(
x = x,
y1 = rep(letters[1:3], c(80, 70, 50)) |> sample(),
y2 = rep(letters[2:5], c(60, 80, 40, 20)) |> sample()
)
x_df |>
pad() |>
fill_by_prevalent(y1, y2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.