View source: R/fill_functions.R
| fill_by_value | R Documentation |
Replace all missing values in the specified columns by the same value.
fill_by_value(x, ..., value = 0)
x |
A data frame. |
... |
The unquoted column names of the variables that should be filled. |
value |
The value to replace the missing values by. |
x with the altered columns.
x <- seq(as.Date("2016-01-01"), by = "day", length.out = 366)
x <- x[sample(1:366, 200)] |> sort()
x_df <- data.frame(
x = x,
y1 = runif(200, 10, 20) |> round(),
y2 = runif(200, 1, 50) |> round(),
y3 = runif(200, 20, 40) |> round(),
y4 = sample(letters[1:5], 200, replace = TRUE)
)
x_padded <- x_df |> pad()
x_padded |> fill_by_value(y1)
x_df |>
pad() |>
fill_by_value(y1, y2, value = 42)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.